From c97793e5a53eb01a10d489bcd98b1ed46a30f0b7 Mon Sep 17 00:00:00 2001
Date: Fri, 20 Dec 2013 22:27:55 -0600
Subject: [PATCH] Added support for MSC_IMAGE_FORMAT to allow for specifying
 the output type for mscgen.

---
 src/config.xml | 14 ++++++++++++++
 src/msc.cpp    | 18 +++++-------------
 src/msc.h      |  2 +-
 3 files changed, 20 insertions(+), 14 deletions(-)

diff --git a/src/config.xml b/src/config.xml
index eff8cff..8fda09c 100644
--- a/src/config.xml
+++ b/src/config.xml
@@ -3231,6 +3231,20 @@ to be found in the default search path.
       <value name='gif'/>
       <value name='svg'/>
     </option>
+    <option type='enum' id='MSC_IMAGE_FORMAT' defval='png'>
+      <docs>
+<![CDATA[
+ The \c MSC_IMAGE_FORMAT tag can be used to set the image format of the images
+ generated by \c mscgen.
+ \note If you choose \c svg you need to set 
+ \ref cfg_html_file_extension "HTML_FILE_EXTENSION" to \c xhtml in order to make the SVG files
+ visible in IE 9+ (other browsers do not have this requirement).
+]]>
+      </docs>
+      <value name='png'/>
+      <value name='svg'/>
+      <value name='eps'/>
+    </option>
     <option type='bool' id='INTERACTIVE_SVG' defval='0' depends='HAVE_DOT'>
       <docs>
 <![CDATA[
diff --git a/src/msc.cpp b/src/msc.cpp
index 069bcdd..cd3e4b9 100644
--- a/src/msc.cpp
+++ b/src/msc.cpp
@@ -101,18 +101,10 @@ void writeMscGraphFromFile(const char *inFile,const char *outDir,
   QDir::setCurrent(outDir);
   //printf("Going to dir %s\n",QDir::currentDirPath().data());
   QCString mscExe = Config_getString("MSCGEN_PATH")+"mscgen"+portable_commandExtension();
-  QCString mscArgs;
-  QCString extension;
-  if (format==MSC_BITMAP)
-  {
-    mscArgs+="-T png";
-    extension=".png";
-  }
-  else if (format==MSC_EPS)
-  {
-    mscArgs+="-T eps";
-    extension=".eps";
-  }
+  QCString mscType = Config_getEnum("MSC_IMAGE_FORMAT");
+  QCString mscArgs = "-T "+mscType;
+  QCString extension = "."+mscType;
+
   mscArgs+=" -i \"";
   mscArgs+=inFile;
  
@@ -192,7 +184,7 @@ void writeMscImageMapFromFile(FTextStream &t,const QCString &inFile,
 {
   QCString mapName = baseName+".map";
   QCString mapFile = inFile+".map";
-  t << "<img src=\"" << relPath << baseName << ".png\" alt=\""
+  t << "<img src=\"" << relPath << baseName << "." << Config_getEnum("MSC_IMAGE_FORMAT") << "\" alt=\""
     << baseName << "\" border=\"0\" usemap=\"#" << mapName << "\"/>" << endl;
   QCString imap = getMscImageMapFromFile(inFile,outDir,relPath,context);
   t << "<map name=\"" << mapName << "\" id=\"" << mapName << "\">" << imap << "</map>" << endl;
diff --git a/src/msc.h b/src/msc.h
index 711e3de..3af4c0b 100644
--- a/src/msc.h
+++ b/src/msc.h
@@ -21,7 +21,7 @@
 class QCString;
 class FTextStream;
 
-enum MscOutputFormat { MSC_BITMAP , MSC_EPS };
+enum MscOutputFormat { MSC_BITMAP , MSC_EPS, MSC_SVG };
 
 void writeMscGraphFromFile(const char *inFile,const char *outDir,
                            const char *outFile,MscOutputFormat format);
-- 
1.8.1.5

